/*******************************************************************************
* File Name: SAR_ADC.h
* Version 2.30
*
* Description:
*  This file contains the function prototypes and constants used in
*  the Sequencing Successive Approximation ADC Component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_ADC_SAR_SEQ_SAR_ADC_H)
#define CY_ADC_SAR_SEQ_SAR_ADC_H

#include "cytypes.h"
#include "CyLib.h"


/***************************************
*      Data Struct Definition
***************************************/

/* Sleep Mode API Support */
typedef struct
{
    uint8 enableState;
} SAR_ADC_BACKUP_STRUCT;


/**************************************
*    Enumerated Types and Parameters
**************************************/

/*  Clock Source setting constants */
#define SAR_ADC__EXTERNAL 0
#define SAR_ADC__INTERNAL 1

/*  Sample Mode setting constants */
#define SAR_ADC__FREERUNNING 0
#define SAR_ADC__HARDWARESOC 1

/*  Reference type setting constants */
#define SAR_ADC__VDDA_2 0
#define SAR_ADC__VDDA 1
#define SAR_ADC__INTERNAL1024 2
#define SAR_ADC__INTERNAL1024BYPASSED 3
#define SAR_ADC__INTERNALVREF 4
#define SAR_ADC__INTERNALVREFBYPASSED 5
#define SAR_ADC__VDDA_2BYPASSED 6
#define SAR_ADC__EXTERNALVREF 7

/* Input buffer gain setting constants */
#define SAR_ADC__DISABLED 0
#define SAR_ADC__ONE 1
#define SAR_ADC__TWO 2
#define SAR_ADC__FOUR 3
#define SAR_ADC__EIGHT 4
#define SAR_ADC__SIXTEEN 5

/* Negative input setting sonstants in single ended mode */
#define SAR_ADC__VSS 0
#define SAR_ADC__VREF 1
#define SAR_ADC__OTHER 2

/* Compare mode setting constants:
*    Mode0 - Disable
*    Mode1 - Result < Low_Limit
*    Mode2 - Low_Limit <= Result < High_Limit
*    Mode3 - High_Limit <= Result
*    Mode4 - (Result < Low_Limit) or (High_Limit <= Result)
*/
#define SAR_ADC__MODE0 0
#define SAR_ADC__MODE1 1
#define SAR_ADC__MODE2 2
#define SAR_ADC__MODE3 3

#define SAR_ADC__RES8 0
#define SAR_ADC__RES10 1

#define SAR_ADC__RIGHT 0
#define SAR_ADC__LEFT 1

#define SAR_ADC__FSIGNED 1
#define SAR_ADC__FUNSIGNED 0

#define SAR_ADC__ACCUMULATE 0
#define SAR_ADC__FIXEDRESOLUTION 1



/***************************************
*   Conditional Compilation Parameters
****************************************/ 

#define SAR_ADC_CY_SAR_IP_VER0               	(0u)
#define SAR_ADC_CY_SAR_IP_VER1               	(1u)

#if (CY_PSOC4_4100 || CY_PSOC4_4200)
    #define SAR_ADC_CY_SAR_IP_VER              (SAR_ADC_CY_SAR_IP_VER0)
#else /* Other devices */
    #define SAR_ADC_CY_SAR_IP_VER              (SAR_ADC_CY_SAR_IP_VER1)
#endif  /* (CY_PSOC4_4100 || CY_PSOC4_4200) */


/***************************************
*    Initial Parameter Constants
***************************************/
#define SAR_ADC_DEFAULT_SAMPLE_MODE_SEL        (0u)
#define SAR_ADC_DEFAULT_VREF_SEL               (1u)
#define SAR_ADC_DEFAULT_NEG_INPUT_SEL          (0u)
#define SAR_ADC_DEFAULT_ALT_RESOLUTION_SEL     (0u)
#define SAR_ADC_DEFAULT_JUSTIFICATION_SEL      (0u)
#define SAR_ADC_DEFAULT_DIFF_RESULT_FORMAT_SEL (0u)
#define SAR_ADC_DEFAULT_SE_RESULT_FORMAT_SEL   (1u)
#define SAR_ADC_DEFAULT_CLOCK_SOURCE           (1u)
#define SAR_ADC_DEFAULT_VREF_MV_VALUE          (3300)
#define SAR_ADC_DEFAULT_BUFFER_GAIN            (0u)
#define SAR_ADC_DEFAULT_AVG_SAMPLES_NUM        (1u)
#define SAR_ADC_DEFAULT_AVG_SAMPLES_DIV        (int16)(0x100u >> (7u - 1u))
#define SAR_ADC_DEFAULT_AVG_MODE               (1u)
#define SAR_ADC_MAX_RESOLUTION                 (12u)
#define SAR_ADC_DEFAULT_LOW_LIMIT              (0u)
#define SAR_ADC_DEFAULT_HIGH_LIMIT             (2047u)
#define SAR_ADC_DEFAULT_COMPARE_MODE           (0u)
#define SAR_ADC_DEFAULT_ACLKS_NUM              (4u)
#define SAR_ADC_DEFAULT_BCLKS_NUM              (4u)
#define SAR_ADC_DEFAULT_CCLKS_NUM              (4u)
#define SAR_ADC_DEFAULT_DCLKS_NUM              (4u)
#define SAR_ADC_TOTAL_CHANNELS_NUM             (3u)
#define SAR_ADC_SEQUENCED_CHANNELS_NUM         (3u)
#define SAR_ADC_DEFAULT_EN_CHANNELS            (7u)
#define SAR_ADC_NOMINAL_CLOCK_FREQ             (1000000)
#define SAR_ADC_INJ_CHANNEL_ENABLED            (0u)
#define SAR_ADC_IRQ_REMOVE                     (0u)

/* Determines whether the configuration contains external negative input. */
#define SAR_ADC_SINGLE_PRESENT                 (0u)
#define SAR_ADC_CHANNELS_MODE                  (0u)
#define SAR_ADC_MAX_CHANNELS_EN_MASK           (0xffffu >> (16u - SAR_ADC_SEQUENCED_CHANNELS_NUM))


/***************************************
*        Function Prototypes
***************************************/

void SAR_ADC_Start(void);
void SAR_ADC_Stop(void);
void SAR_ADC_Init(void);
void SAR_ADC_Enable(void);
void SAR_ADC_StartConvert(void);
void SAR_ADC_StopConvert(void);
uint32 SAR_ADC_IsEndConversion(uint32 retMode);
int16 SAR_ADC_GetResult16(uint32 chan);
void SAR_ADC_SetChanMask(uint32 mask);
void SAR_ADC_SetLowLimit(uint32 lowLimit);
void SAR_ADC_SetHighLimit(uint32 highLimit);
void SAR_ADC_SetLimitMask(uint32 mask);
void SAR_ADC_SetSatMask(uint32 mask);
void SAR_ADC_SetOffset(uint32 chan, int16 offset);
void SAR_ADC_SetGain(uint32 chan, int32 adcGain);
#if(SAR_ADC_INJ_CHANNEL_ENABLED)
    void SAR_ADC_EnableInjection(void);
#endif /* SAR_ADC_INJ_CHANNEL_ENABLED */
#if(SAR_ADC_DEFAULT_JUSTIFICATION_SEL == SAR_ADC__RIGHT)
    int16 SAR_ADC_CountsTo_mVolts(uint32 chan, int16 adcCounts);
    int32 SAR_ADC_CountsTo_uVolts(uint32 chan, int16 adcCounts);
    float32 SAR_ADC_CountsTo_Volts(uint32 chan, int16 adcCounts);
#endif /* End SAR_ADC_DEFAULT_JUSTIFICATION_SEL == SAR_ADC__RIGHT */
void SAR_ADC_Sleep(void);
void SAR_ADC_Wakeup(void);
void SAR_ADC_SaveConfig(void);
void SAR_ADC_RestoreConfig(void);

CY_ISR_PROTO( SAR_ADC_ISR );


/**************************************
*           API Constants
**************************************/
/* Constants for Sleep mode states */
#define SAR_ADC_DISABLED                   (0x00u)
#define SAR_ADC_ENABLED                    (0x01u)
#define SAR_ADC_STARTED                    (0x02u)
#define SAR_ADC_BOOSTPUMP_ENABLED          (0x04u)

/*   Constants for IsEndConversion() "retMode" parameter  */
#define SAR_ADC_RETURN_STATUS              (0x01u)
#define SAR_ADC_WAIT_FOR_RESULT            (0x02u)
#define SAR_ADC_RETURN_STATUS_INJ          (0x04u)
#define SAR_ADC_WAIT_FOR_RESULT_INJ        (0x08u)

#define SAR_ADC_MAX_FREQUENCY              (18000000)       /*18Mhz*/

#define SAR_ADC_RESOLUTION_12              (12u)
#define SAR_ADC_RESOLUTION_10              (10u)
#define SAR_ADC_RESOLUTION_8               (8u)

#define SAR_ADC_10US_DELAY                 (10u)

#define SAR_ADC_10V_COUNTS                 (10.0F)
#define SAR_ADC_10MV_COUNTS                (10000)
#define SAR_ADC_10UV_COUNTS                (10000000L)


/***************************************
* Global variables external identifier
***************************************/

extern uint8 SAR_ADC_initVar;
extern volatile int16 SAR_ADC_offset[SAR_ADC_TOTAL_CHANNELS_NUM];
extern volatile int32 SAR_ADC_countsPer10Volt[SAR_ADC_TOTAL_CHANNELS_NUM];


/***************************************
*              Registers
***************************************/

#define SAR_ADC_SAR_CTRL_REG                (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_CTRL )
#define SAR_ADC_SAR_CTRL_PTR                ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_CTRL )

#define SAR_ADC_SAR_SAMPLE_CTRL_REG         (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_SAMPLE_CTRL )
#define SAR_ADC_SAR_SAMPLE_CTRL_PTR         ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_SAMPLE_CTRL )

#define SAR_ADC_SAR_SAMPLE_TIME01_REG       (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_SAMPLE_TIME01 )
#define SAR_ADC_SAR_SAMPLE_TIME01_PTR       ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_SAMPLE_TIME01 )

#define SAR_ADC_SAR_SAMPLE_TIME23_REG       (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_SAMPLE_TIME23 )
#define SAR_ADC_SAR_SAMPLE_TIME23_PTR       ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_SAMPLE_TIME23 )

#define SAR_ADC_SAR_RANGE_THRES_REG         (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_RANGE_THRES )
#define SAR_ADC_SAR_RANGE_THRES_PTR         ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_RANGE_THRES )

#define SAR_ADC_SAR_RANGE_COND_REG          (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_RANGE_COND )
#define SAR_ADC_SAR_RANGE_COND_PTR          ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_RANGE_COND )

#define SAR_ADC_SAR_CHAN_EN_REG             (*(reg32 *) CYREG_SAR_CHAN_EN )
#define SAR_ADC_SAR_CHAN_EN_PTR             ( (reg32 *) CYREG_SAR_CHAN_EN )

#define SAR_ADC_SAR_START_CTRL_REG          (*(reg32 *) CYREG_SAR_START_CTRL )
#define SAR_ADC_SAR_START_CTRL_PTR          ( (reg32 *) CYREG_SAR_START_CTRL )

#define SAR_ADC_SAR_DFT_CTRL_REG            (*(reg32 *) CYREG_SAR_DFT_CTRL )
#define SAR_ADC_SAR_DFT_CTRL_PTR            ( (reg32 *) CYREG_SAR_DFT_CTRL )

#define SAR_ADC_SAR_CHAN_CONFIG_REG         (*(reg32 *) CYREG_SAR_CHAN_CONFIG00 )
#define SAR_ADC_SAR_CHAN_CONFIG_PTR         ( (reg32 *) CYREG_SAR_CHAN_CONFIG00 )
#define SAR_ADC_SAR_CHAN_CONFIG_IND         CYREG_SAR_CHAN_CONFIG00

#define SAR_ADC_SAR_CHAN_WORK_REG           (*(reg32 *) CYREG_SAR_CHAN_WORK00 )
#define SAR_ADC_SAR_CHAN_WORK_PTR           ( (reg32 *) CYREG_SAR_CHAN_WORK00 )

#define SAR_ADC_SAR_CHAN_RESULT_REG         (*(reg32 *) CYREG_SAR_CHAN_RESULT00 )
#define SAR_ADC_SAR_CHAN_RESULT_PTR         ( (reg32 *) CYREG_SAR_CHAN_RESULT00 )
#define SAR_ADC_SAR_CHAN_RESULT_IND         CYREG_SAR_CHAN_RESULT00

#define SAR_ADC_SAR_CHAN0_RESULT_REG         (*(reg32 *) CYREG_SAR_CHAN_RESULT00 )
#define SAR_ADC_SAR_CHAN0_RESULT_PTR         ( (reg32 *) CYREG_SAR_CHAN_RESULT00 )

#define SAR_ADC_SAR_CHAN1_RESULT_REG         (*(reg32 *) CYREG_SAR_CHAN_RESULT01 )
#define SAR_ADC_SAR_CHAN1_RESULT_PTR         ( (reg32 *) CYREG_SAR_CHAN_RESULT01 )

#define SAR_ADC_SAR_CHAN2_RESULT_REG         (*(reg32 *) CYREG_SAR_CHAN_RESULT02 )
#define SAR_ADC_SAR_CHAN2_RESULT_PTR         ( (reg32 *) CYREG_SAR_CHAN_RESULT02 )

#define SAR_ADC_SAR_CHAN3_RESULT_REG         (*(reg32 *) CYREG_SAR_CHAN_RESULT03 )
#define SAR_ADC_SAR_CHAN3_RESULT_PTR         ( (reg32 *) CYREG_SAR_CHAN_RESULT03 )

#define SAR_ADC_SAR_CHAN4_RESULT_REG         (*(reg32 *) CYREG_SAR_CHAN_RESULT04 )
#define SAR_ADC_SAR_CHAN4_RESULT_PTR         ( (reg32 *) CYREG_SAR_CHAN_RESULT04 )

#define SAR_ADC_SAR_CHAN5_RESULT_REG         (*(reg32 *) CYREG_SAR_CHAN_RESULT05 )
#define SAR_ADC_SAR_CHAN5_RESULT_PTR         ( (reg32 *) CYREG_SAR_CHAN_RESULT05 )

#define SAR_ADC_SAR_CHAN6_RESULT_REG         (*(reg32 *) CYREG_SAR_CHAN_RESULT06 )
#define SAR_ADC_SAR_CHAN6_RESULT_PTR         ( (reg32 *) CYREG_SAR_CHAN_RESULT06 )

#define SAR_ADC_SAR_CHAN7_RESULT_REG         (*(reg32 *) CYREG_SAR_CHAN_RESULT07 )
#define SAR_ADC_SAR_CHAN7_RESULT_PTR         ( (reg32 *) CYREG_SAR_CHAN_RESULT07 )

#if(SAR_ADC_CY_SAR_IP_VER != SAR_ADC_CY_SAR_IP_VER0)
    #define SAR_ADC_SAR_CHAN8_RESULT_REG         (*(reg32 *) CYREG_SAR_CHAN_RESULT08 )
    #define SAR_ADC_SAR_CHAN8_RESULT_PTR         ( (reg32 *) CYREG_SAR_CHAN_RESULT08 )

    #define SAR_ADC_SAR_CHAN9_RESULT_REG         (*(reg32 *) CYREG_SAR_CHAN_RESULT09 )
    #define SAR_ADC_SAR_CHAN9_RESULT_PTR         ( (reg32 *) CYREG_SAR_CHAN_RESULT09 )

    #define SAR_ADC_SAR_CHAN10_RESULT_REG         (*(reg32 *) CYREG_SAR_CHAN_RESULT010 )
    #define SAR_ADC_SAR_CHAN10_RESULT_PTR         ( (reg32 *) CYREG_SAR_CHAN_RESULT010 )

    #define SAR_ADC_SAR_CHAN11_RESULT_REG         (*(reg32 *) CYREG_SAR_CHAN_RESULT011 )
    #define SAR_ADC_SAR_CHAN11_RESULT_PTR         ( (reg32 *) CYREG_SAR_CHAN_RESULT011 )

    #define SAR_ADC_SAR_CHAN12_RESULT_REG         (*(reg32 *) CYREG_SAR_CHAN_RESULT012 )
    #define SAR_ADC_SAR_CHAN12_RESULT_PTR         ( (reg32 *) CYREG_SAR_CHAN_RESULT012 )

    #define SAR_ADC_SAR_CHAN13_RESULT_REG         (*(reg32 *) CYREG_SAR_CHAN_RESULT013 )
    #define SAR_ADC_SAR_CHAN13_RESULT_PTR         ( (reg32 *) CYREG_SAR_CHAN_RESULT013 )

    #define SAR_ADC_SAR_CHAN14_RESULT_REG         (*(reg32 *) CYREG_SAR_CHAN_RESULT014 )
    #define SAR_ADC_SAR_CHAN14_RESULT_PTR         ( (reg32 *) CYREG_SAR_CHAN_RESULT014 )

    #define SAR_ADC_SAR_CHAN15_RESULT_REG         (*(reg32 *) CYREG_SAR_CHAN_RESULT015 )
    #define SAR_ADC_SAR_CHAN15_RESULT_PTR         ( (reg32 *) CYREG_SAR_CHAN_RESULT015 )
#endif /* (SAR_ADC_CY_SAR_IP_VER != SAR_ADC_CY_SAR_IP_VER0) */

#define SAR_ADC_SAR_CHAN_WORK_VALID_REG     (*(reg32 *) CYREG_SAR_CHAN_WORK_VALID)
#define SAR_ADC_SAR_CHAN_WORK_VALID_PTR     ( (reg32 *) CYREG_SAR_CHAN_WORK_VALID)

#define SAR_ADC_SAR_CHAN_RESULT_VALID_REG   ( *(reg32 *) CYREG_SAR_CHAN_RESULT_VALID )
#define SAR_ADC_SAR_CHAN_RESULT_VALID_PTR   ( (reg32 *) CYREG_SAR_CHAN_RESULT_VALID )

#define SAR_ADC_SAR_STATUS_REG              (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_STATUS )
#define SAR_ADC_SAR_STATUS_PTR              ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_STATUS )

#define SAR_ADC_SAR_AVG_START_REG           (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_AVG_STAT )
#define SAR_ADC_SAR_AVG_START_PTR           ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_AVG_STAT )

#define SAR_ADC_SAR_INTR_REG                (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_INTR )
#define SAR_ADC_SAR_INTR_PTR                ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_INTR )

#define SAR_ADC_SAR_INTR_SET_REG            (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_INTR_SET )
#define SAR_ADC_SAR_INTR_SET_PTR            ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_INTR_SET )

#define SAR_ADC_SAR_INTR_MASK_REG           (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_INTR_MASK )
#define SAR_ADC_SAR_INTR_MASK_PTR           ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_INTR_MASK )

#define SAR_ADC_SAR_INTR_MASKED_REG         (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_INTR_MASKED )
#define SAR_ADC_SAR_INTR_MASKED_PTR         ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_INTR_MASKED )

#define SAR_ADC_SAR_SATURATE_INTR_REG       (*(reg32 *) CYREG_SAR_SATURATE_INTR )
#define SAR_ADC_SAR_SATURATE_INTR_PTR       ( (reg32 *) CYREG_SAR_SATURATE_INTR )

#define SAR_ADC_SAR_SATURATE_INTR_SET_REG   (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_SATURATE_INTR_SET )
#define SAR_ADC_SAR_SATURATE_INTR_SET_PTR   ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_SATURATE_INTR_SET )

#define SAR_ADC_SAR_SATURATE_INTR_MASK_REG  (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_SATURATE_INTR_MASK )
#define SAR_ADC_SAR_SATURATE_INTR_MASK_PTR  ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_SATURATE_INTR_MASK )

#define SAR_ADC_SAR_SATURATE_INTR_MASKED_REG \
                                                 (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_SATURATE_INTR_MASKED )
#define SAR_ADC_SAR_SATURATE_INTR_MASKED_PTR \
                                                 ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_SATURATE_INTR_MASKED )

#define SAR_ADC_SAR_RANGE_INTR_REG          (*(reg32 *) CYREG_SAR_RANGE_INTR )
#define SAR_ADC_SAR_RANGE_INTR_PTR          ( (reg32 *) CYREG_SAR_RANGE_INTR )

#define SAR_ADC_SAR_RANGE_INTR_SET_REG      (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_RANGE_INTR_SET )
#define SAR_ADC_SAR_RANGE_INTR_SET_PTR      ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_RANGE_INTR_SET )

#define SAR_ADC_SAR_RANGE_INTR_MASK_REG     (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_RANGE_INTR_MASK )
#define SAR_ADC_SAR_RANGE_INTR_MASK_PTR     ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_RANGE_INTR_MASK )

#define SAR_ADC_SAR_RANGE_INTR_MASKED_REG   (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_RANGE_INTR_MASKED )
#define SAR_ADC_SAR_RANGE_INTR_MASKED_PTR   ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_RANGE_INTR_MASKED )

#define SAR_ADC_SAR_INTR_CAUSE_REG          (*(reg32 *) SAR_ADC_cy_psoc4_sar__SAR_INTR_CAUSE )
#define SAR_ADC_SAR_INTR_CAUSE_PTR          ( (reg32 *) SAR_ADC_cy_psoc4_sar__SAR_INTR_CAUSE )

#define SAR_ADC_SAR_INJ_CHAN_CONFIG_REG     (*(reg32 *) CYREG_SAR_INJ_CHAN_CONFIG)
#define SAR_ADC_SAR_INJ_CHAN_CONFIG_PTR     ( (reg32 *) CYREG_SAR_INJ_CHAN_CONFIG)

#define SAR_ADC_SAR_INJ_RESULT_REG          (*(reg32 *) CYREG_SAR_INJ_RESULT )
#define SAR_ADC_SAR_INJ_RESULT_PTR          ( (reg32 *) CYREG_SAR_INJ_RESULT )

#define SAR_ADC_MUX_SWITCH0_REG             (*(reg32 *)  CYREG_SAR_MUX_SWITCH0 )
#define SAR_ADC_MUX_SWITCH0_PTR             ( (reg32 *)  CYREG_SAR_MUX_SWITCH0 )

#define SAR_ADC_MUX_SWITCH_HW_CTRL_REG      (*(reg32 *)  CYREG_SAR_MUX_SWITCH_HW_CTRL )
#define SAR_ADC_MUX_SWITCH_HW_CTRL_PTR      ( (reg32 *)  CYREG_SAR_MUX_SWITCH_HW_CTRL )

#define SAR_ADC_PUMP_CTRL_REG               (*(reg32 *)  CYREG_SAR_PUMP_CTRL )
#define SAR_ADC_PUMP_CTRL_PTR               ( (reg32 *)  CYREG_SAR_PUMP_CTRL )

#define SAR_ADC_ANA_TRIM_REG                (*(reg32 *)  CYREG_SAR_ANA_TRIM )
#define SAR_ADC_ANA_TRIM_PTR                ( (reg32 *)  CYREG_SAR_ANA_TRIM )

#define SAR_ADC_WOUNDING_REG                (*(reg32 *)  CYREG_SAR_WOUNDING )
#define SAR_ADC_WOUNDING_PTR                ( (reg32 *)  CYREG_SAR_WOUNDING )


/**************************************
*       Register Constants
**************************************/
#define SAR_ADC_INTC_NUMBER                (SAR_ADC_IRQ__INTC_NUMBER)
#define SAR_ADC_INTC_PRIOR_NUMBER          (SAR_ADC_IRQ__INTC_PRIOR_NUM)

/* defines for CTRL register */
#define SAR_ADC_VREF_INTERNAL1024          (0x00000040Lu)
#define SAR_ADC_VREF_EXTERNAL              (0x00000050Lu)
#define SAR_ADC_VREF_VDDA_2                (0x00000060Lu)
#define SAR_ADC_VREF_VDDA                  (0x00000070Lu)
#define SAR_ADC_VREF_INTERNAL1024BYPASSED  (0x000000C0Lu)
#define SAR_ADC_VREF_VDDA_2BYPASSED        (0x000000E0Lu)
#define SAR_ADC_VREF_INTERNALVREF          (0x00000000Lu)
#define SAR_ADC_VREF_INTERNALVREFBYPASSED  (0x00000000Lu)

#define SAR_ADC_NEG_VSSA_KELVIN            (0x00000000Lu)
#define SAR_ADC_NEG_VSSA                   (0x00000200Lu)
#define SAR_ADC_NEG_VREF                   (0x00000E00Lu)
#if(SAR_ADC_TOTAL_CHANNELS_NUM > 1u)
    #define SAR_ADC_NEG_OTHER              (uint16)((uint16)SAR_ADC_cy_psoc4_sarmux_8__VNEG << 9u)
#else
    #define SAR_ADC_NEG_OTHER              (0)
#endif /* SAR_ADC_TOTAL_CHANNELS_NUM > 1u */

#define SAR_ADC_SAR_HW_CTRL_NEGVREF        (0x00002000Lu)

#define SAR_ADC_BOOSTPUMP_EN               (0x00100000Lu)

#define SAR_ADC_NORMAL_PWR                 (0x00000000Lu)
#define SAR_ADC_HALF_PWR                   (0x01000000Lu)
#define SAR_ADC_MORE_PWR                   (0x02000000Lu)
#define SAR_ADC_QUARTER_PWR                (0x03000000Lu)
#define SAR_ADC_DEEPSLEEP_ON               (0x08000000Lu)

#define SAR_ADC_DSI_SYNC_CONFIG            (0x10000000Lu)
#define SAR_ADC_DSI_MODE                   (0x20000000Lu)
#define SAR_ADC_SWITCH_DISABLE             (0x40000000Lu)
#define SAR_ADC_ENABLE                     (0x80000000Lu)

/* defines for STATUS register */
#define SAR_ADC_STATUS_BUSY                (0x80000000Lu)

/* defines for SAMPLE_CTRL register */
#define SAR_ADC_ALT_RESOLUTION_10BIT       (0x00000001Lu)
#define SAR_ADC_ALT_RESOLUTION_8BIT        (0x00000000Lu)

#define SAR_ADC_DATA_ALIGN_LEFT            (0x00000002Lu)
#define SAR_ADC_DATA_ALIGN_RIGHT           (0x00000000Lu)

#define SAR_ADC_SE_SIGNED_RESULT           (0x00000004Lu)
#define SAR_ADC_SE_UNSIGNED_RESULT         (0x00000000Lu)

#define SAR_ADC_DIFF_SIGNED_RESULT         (0x00000008Lu)
#define SAR_ADC_DIFF_UNSIGNED_RESULT       (0x00000000Lu)

#define SAR_ADC_AVG_CNT_OFFSET             (4u)
#define SAR_ADC_AVG_CNT_MASK               (0x00000070Lu)
#define SAR_ADC_AVG_SHIFT                  (0x00000080Lu)

#define SAR_ADC_CONTINUOUS_EN              (0x00010000Lu)
#define SAR_ADC_DSI_TRIGGER_EN             (0x00020000Lu)
#define SAR_ADC_DSI_TRIGGER_LEVEL          (0x00040000Lu)
#define SAR_ADC_DSI_SYNC_TRIGGER           (0x00080000Lu)
#define SAR_ADC_EOS_DSI_OUT_EN             (0x80000000Lu)

/* defines for SAMPLE_TIME01 / SAMPLE_TIME23 registers */
#define SAR_ADC_SAMPLE_TIME13_OFFSET       (16u)
#define SAR_ADC_SAMPLE_TIME02_MASK         (0x000003FFLu)
#define SAR_ADC_SAMPLE_TIME13_MASK         (0x03FF0000Lu)

/* defines for RANGE_THRES registers */
#define SAR_ADC_RANGE_HIGH_OFFSET          (16u)
#define SAR_ADC_RANGE_HIGH_MASK            (0xFFFF0000Lu)
#define SAR_ADC_RANGE_LOW_MASK             (0x0000FFFFLu)

/* defines for RANGE_COND register */
/* Compare mode setting constants:
*    BELOW   - Result < Low_Limit
*    INSIDE  - Low_Limit <= Result < High_Limit
*    ABOVE   - High_Limit <= Result
*    OUTSIDE - (Result < Low_Limit) or (High_Limit <= Result)
*/
#define SAR_ADC_CMP_MODE_BELOW             (0x00000000Lu)
#define SAR_ADC_CMP_MODE_INSIDE            (0x40000000Lu)
#define SAR_ADC_CMP_MODE_ABOVE             (0x80000000Lu)
#define SAR_ADC_CMP_MODE_OUTSIDE           (0xC0000000Lu)
#define SAR_ADC_CMP_OFFSET                 (30u)

/* defines for _START_CTRL register */
#define SAR_ADC_FW_TRIGGER                 (0x00000001Lu)

/* defines for DFT_CTRL register */
#define SAR_ADC_DLY_INC                    (0x00000001Lu)
#define SAR_ADC_HIZ                        (0x00000002Lu)
#define SAR_ADC_DFT_INC_MASK               (0x000F0000Lu)
#define SAR_ADC_DFT_OUTC_MASK              (0x00700000Lu)
#define SAR_ADC_SEL_CSEL_DFT_MASK          (0x0F000000Lu)

/* configuration for clock speed > 9 Mhz based on
* characterization results
*/
#define SAR_ADC_SEL_CSEL_DFT_CHAR          (0x03000000Lu)
#define SAR_ADC_EN_CSEL_DFT                (0x10000000Lu)
#define SAR_ADC_DCEN                       (0x20000000Lu)
#define SAR_ADC_ADFT_OVERRIDE              (0x80000000Lu)

/* defines for CHAN_CONFIG / DIE_CHAN_CONFIG register
*  and channelsConfig parameter
*/
#define SAR_ADC_SARMUX_VIRT_SELECT         (0x00000070Lu)
#define SAR_ADC_DIFFERENTIAL_EN            (0x00000100Lu)
#define SAR_ADC_ALT_RESOLUTION_ON          (0x00000200Lu)
#define SAR_ADC_AVERAGING_EN               (0x00000400Lu)

#define SAR_ADC_SAMPLE_TIME_SEL_SHIFT      (12u)
#define SAR_ADC_SAMPLE_TIME_SEL_MASK       (0x00003000Lu)

#define SAR_ADC_CHANNEL_CONFIG_MASK        (0x00003700Lu)

/* for CHAN_CONFIG only */
#define SAR_ADC_DSI_OUT_EN                 (0x80000000Lu)

/* for INJ_CHAN_CONFIG only */
#define SAR_ADC_INJ_TAILGATING             (0x40000000Lu)
#define SAR_ADC_INJ_CHAN_EN                (0x80000000Lu)

/* defines for CHAN_WORK register */
#define SAR_ADC_SAR_WRK_MAX_12BIT          (0x00001000Lu)
#define SAR_ADC_SAR_WRK_MAX_10BIT          (0x00000400Lu)
#define SAR_ADC_SAR_WRK_MAX_8BIT           (0x00000100Lu)

/* defines for CHAN_RESULT register */
#define SAR_ADC_RESULT_MASK                (0x0000FFFFLu)
#define SAR_ADC_SATURATE_INTR_MIR          (0x20000000Lu)
#define SAR_ADC_RANGE_INTR_MIR             (0x40000000Lu)
#define SAR_ADC_CHAN_RESULT_VALID_MIR      (0x80000000Lu)

/* defines for INTR_MASK register */
#define SAR_ADC_EOS_MASK                   (0x00000001Lu)
#define SAR_ADC_OVERFLOW_MASK              (0x00000002Lu)
#define SAR_ADC_FW_COLLISION_MASK          (0x00000004Lu)
#define SAR_ADC_DSI_COLLISION_MASK         (0x00000008Lu)
#define SAR_ADC_INJ_EOC_MASK               (0x00000010Lu)
#define SAR_ADC_INJ_SATURATE_MASK          (0x00000020Lu)
#define SAR_ADC_INJ_RANGE_MASK             (0x00000040Lu)
#define SAR_ADC_INJ_COLLISION_MASK         (0x00000080Lu)

/* defines for INJ_RESULT register */
#define SAR_ADC_INJ_COLLISION_INTR_MIR     (0x10000000Lu)
#define SAR_ADC_INJ_SATURATE_INTR_MIR      (0x20000000Lu)
#define SAR_ADC_INJ_RANGE_INTR_MIR         (0x40000000Lu)
#define SAR_ADC_INJ_EOC_INTR_MIR           (0x80000000Lu)

/* defines for MUX_SWITCH0 register */
#define SAR_ADC_MUX_FW_VSSA_VMINUS         (0x00010000Lu)

/* defines for PUMP_CTRL register */
#define SAR_ADC_PUMP_CTRL_ENABLED          (0x80000000Lu)

/* additional defines for channelsConfig parameter */
#define SAR_ADC_IS_SATURATE_EN_MASK        (0x00000001Lu)
#define SAR_ADC_IS_RANGE_CTRL_EN_MASK      (0x00000002Lu)

/* defines for WOUNDING register */
#define SAR_ADC_WOUNDING_12BIT             (0x00000000Lu)
#define SAR_ADC_WOUNDING_10BIT             (0x00000001Lu)
#define SAR_ADC_WOUNDING_8BIT              (0x00000002Lu)

/* Trim value based on characterization */
#define SAR_ADC_TRIM_COEF                  (2u)

#if(SAR_ADC_MAX_RESOLUTION == SAR_ADC_RESOLUTION_10)
    #define SAR_ADC_ALT_WOUNDING           SAR_ADC_WOUNDING_10BIT
#else
    #define SAR_ADC_ALT_WOUNDING           SAR_ADC_WOUNDING_8BIT
#endif /* SAR_ADC_MAX_RESOLUTION == SAR_ADC_RESOLUTION_10 */

#if(SAR_ADC_DEFAULT_VREF_SEL == SAR_ADC__VDDA_2)
    #define SAR_ADC_DEFAULT_VREF_SOURCE    SAR_ADC_VREF_VDDA_2
#elif(SAR_ADC_DEFAULT_VREF_SEL == SAR_ADC__VDDA)
    #define SAR_ADC_DEFAULT_VREF_SOURCE    SAR_ADC_VREF_VDDA
#elif(SAR_ADC_DEFAULT_VREF_SEL == SAR_ADC__INTERNAL1024)
    #define SAR_ADC_DEFAULT_VREF_SOURCE    SAR_ADC_VREF_INTERNAL1024
#elif(SAR_ADC_DEFAULT_VREF_SEL == SAR_ADC__INTERNAL1024BYPASSED)
    #define SAR_ADC_DEFAULT_VREF_SOURCE    SAR_ADC_VREF_INTERNAL1024BYPASSED
#elif(SAR_ADC_DEFAULT_VREF_SEL == SAR_ADC__INTERNALVREF)
    #define SAR_ADC_DEFAULT_VREF_SOURCE    SAR_ADC_VREF_INTERNALVREF
#elif(SAR_ADC_DEFAULT_VREF_SEL == SAR_ADC__INTERNALVREFBYPASSED)
    #define SAR_ADC_DEFAULT_VREF_SOURCE    SAR_ADC_VREF_INTERNALVREFBYPASSED
#elif(SAR_ADC_DEFAULT_VREF_SEL == SAR_ADC__VDDA_2BYPASSED)
    #define SAR_ADC_DEFAULT_VREF_SOURCE    SAR_ADC_VREF_VDDA_2BYPASSED
#else
    #define SAR_ADC_DEFAULT_VREF_SOURCE    SAR_ADC_VREF_EXTERNAL
#endif /* SAR_ADC_DEFAULT_VREF_SEL == SAR_ADC__VDDA_2 */

#if(SAR_ADC_DEFAULT_NEG_INPUT_SEL == SAR_ADC__VSS)
    /* Connect NEG input of SARADC to VSSA close to the SARADC for single channel mode */
    #if(SAR_ADC_TOTAL_CHANNELS_NUM == 1u)
        #define SAR_ADC_DEFAULT_SE_NEG_INPUT    SAR_ADC_NEG_VSSA
    #else
        #define SAR_ADC_DEFAULT_SE_NEG_INPUT    SAR_ADC_NEG_VSSA_KELVIN
    #endif /* (SAR_ADC_TOTAL_CHANNELS_NUM == 1u) */
    /* Do not connect VSSA to VMINUS when one channel in differential mode used */
    #if((SAR_ADC_TOTAL_CHANNELS_NUM == 1u) && (SAR_ADC_CHANNELS_MODE != 0u))
        #define SAR_ADC_DEFAULT_MUX_SWITCH0     0u
    #else    /* miltiple channels or one single channel */
        #define SAR_ADC_DEFAULT_MUX_SWITCH0     SAR_ADC_MUX_FW_VSSA_VMINUS
    #endif /* (SAR_ADC_TOTAL_CHANNELS_NUM == 1u) */
#elif(SAR_ADC_DEFAULT_NEG_INPUT_SEL == SAR_ADC__VREF)
    /* Do not connect VNEG to VREF when one channel in differential mode used */
    #if((SAR_ADC_TOTAL_CHANNELS_NUM == 1u) && (SAR_ADC_CHANNELS_MODE != 0u))
        #define SAR_ADC_DEFAULT_SE_NEG_INPUT    0u
    #else    /* miltiple channels or one single channel */
        #define SAR_ADC_DEFAULT_SE_NEG_INPUT    SAR_ADC_NEG_VREF
    #endif /* (SAR_ADC_TOTAL_CHANNELS_NUM == 1u) */
    #define SAR_ADC_DEFAULT_MUX_SWITCH0     0u
#elif (SAR_ADC_SINGLE_PRESENT != 0u)
    #define SAR_ADC_DEFAULT_SE_NEG_INPUT    SAR_ADC_NEG_OTHER
    #define SAR_ADC_DEFAULT_MUX_SWITCH0     0u
#else
    #define SAR_ADC_DEFAULT_SE_NEG_INPUT    0u
    #define SAR_ADC_DEFAULT_MUX_SWITCH0     0u
#endif /* SAR_ADC_DEFAULT_NEG_INPUT_SEL == SAR_ADC__VREF */

/* If the SAR is configured for multiple channels, always set SAR_HW_CTRL_NEGVREF to 1 */
#if(SAR_ADC_TOTAL_CHANNELS_NUM == 1u)
    #define SAR_ADC_DEFAULT_HW_CTRL_NEGVREF 0u
#else
    #define SAR_ADC_DEFAULT_HW_CTRL_NEGVREF SAR_ADC_SAR_HW_CTRL_NEGVREF
#endif /* (SAR_ADC_TOTAL_CHANNELS_NUM == 1u) */


#if(SAR_ADC_DEFAULT_ALT_RESOLUTION_SEL == SAR_ADC__RES8)
    #define SAR_ADC_DEFAULT_ALT_RESOLUTION     (SAR_ADC_ALT_RESOLUTION_8BIT)
    #define SAR_ADC_DEFAULT_MAX_WRK_ALT        (SAR_ADC_SAR_WRK_MAX_8BIT)
#else
    #define SAR_ADC_DEFAULT_ALT_RESOLUTION     (SAR_ADC_ALT_RESOLUTION_10BIT)
    #define SAR_ADC_DEFAULT_MAX_WRK_ALT        (SAR_ADC_SAR_WRK_MAX_10BIT)
#endif /* End SAR_ADC_DEFAULT_ALT_RESOLUTION_SEL == SAR_ADC__RES8 */

#if(SAR_ADC_DEFAULT_JUSTIFICATION_SEL == SAR_ADC__RIGHT)
    #define SAR_ADC_DEFAULT_JUSTIFICATION  SAR_ADC_DATA_ALIGN_RIGHT
#else
    #define SAR_ADC_DEFAULT_JUSTIFICATION  SAR_ADC_DATA_ALIGN_LEFT
#endif /* SAR_ADC_DEFAULT_JUSTIFICATION_SEL == SAR_ADC__RIGHT */

#if(SAR_ADC_DEFAULT_DIFF_RESULT_FORMAT_SEL == SAR_ADC__FSIGNED)
    #define SAR_ADC_DEFAULT_DIFF_RESULT_FORMAT SAR_ADC_DIFF_SIGNED_RESULT
#else
    #define SAR_ADC_DEFAULT_DIFF_RESULT_FORMAT SAR_ADC_DIFF_UNSIGNED_RESULT
#endif /* SAR_ADC_DEFAULT_DIFF_RESULT_FORMAT_SEL == SAR_ADC__FSIGNED */

#if(SAR_ADC_DEFAULT_SE_RESULT_FORMAT_SEL == SAR_ADC__FSIGNED)
    #define SAR_ADC_DEFAULT_SE_RESULT_FORMAT SAR_ADC_SE_SIGNED_RESULT
#else
    #define SAR_ADC_DEFAULT_SE_RESULT_FORMAT SAR_ADC_SE_UNSIGNED_RESULT
#endif /* SAR_ADC_DEFAULT_SE_RESULT_FORMAT_SEL == SAR_ADC__FSIGNED */

#if(SAR_ADC_DEFAULT_SAMPLE_MODE_SEL == SAR_ADC__FREERUNNING)
    #define SAR_ADC_DSI_TRIGGER        0u
#else /* Firmware trigger */
    #define SAR_ADC_DSI_TRIGGER        (SAR_ADC_DSI_TRIGGER_EN | SAR_ADC_DSI_SYNC_TRIGGER)
#endif /* End SAR_ADC_DEFAULT_SAMPLE_MODE == SAR_ADC__FREERUNNING */

#if(SAR_ADC_INJ_CHANNEL_ENABLED)
    #define SAR_ADC_SAR_INTR_MASK      (SAR_ADC_EOS_MASK | SAR_ADC_INJ_EOC_MASK)
#else
    #define SAR_ADC_SAR_INTR_MASK      (SAR_ADC_EOS_MASK)
#endif /* SAR_ADC_INJ_CHANNEL_ENABLED*/

#if(SAR_ADC_DEFAULT_AVG_MODE == SAR_ADC__FIXEDRESOLUTION)
    #define SAR_ADC_AVG_SHIFT_MODE     SAR_ADC_AVG_SHIFT
#else
    #define SAR_ADC_AVG_SHIFT_MODE     0u
#endif /* End SAR_ADC_DEFAULT_AVG_MODE */

#define SAR_ADC_COMPARE_MODE           (uint32)((uint32)(SAR_ADC_DEFAULT_COMPARE_MODE) \
                                                << SAR_ADC_CMP_OFFSET)

#if(SAR_ADC_TOTAL_CHANNELS_NUM > 1u)
    #define SAR_ADC_DEFAULT_SWITCH_CONF    0u
#else /* Disable SAR sequencer from enabling routing switches in single channel mode */
    #define SAR_ADC_DEFAULT_SWITCH_CONF    SAR_ADC_SWITCH_DISABLE
#endif /* End SAR_ADC_TOTAL_CHANNELS_NUM > 1 */

#define SAR_ADC_DEFAULT_POWER \
       ((SAR_ADC_NOMINAL_CLOCK_FREQ > (SAR_ADC_MAX_FREQUENCY / 4)) ? SAR_ADC_NORMAL_PWR : \
       ((SAR_ADC_NOMINAL_CLOCK_FREQ > (SAR_ADC_MAX_FREQUENCY / 8)) ? SAR_ADC_HALF_PWR : \
                                                                                       SAR_ADC_QUARTER_PWR))

#define SAR_ADC_DEFAULT_CTRL_REG_CFG       (SAR_ADC_DEFAULT_VREF_SOURCE \
                                                   | SAR_ADC_DEFAULT_SE_NEG_INPUT \
                                                   | SAR_ADC_DEFAULT_HW_CTRL_NEGVREF \
                                                   | SAR_ADC_DEFAULT_POWER \
                                                   | SAR_ADC_DSI_SYNC_CONFIG \
                                                   | SAR_ADC_DEFAULT_SWITCH_CONF)

#define SAR_ADC_DEFAULT_SAMPLE_CTRL_REG_CFG (SAR_ADC_DEFAULT_DIFF_RESULT_FORMAT \
                                                    | SAR_ADC_DEFAULT_SE_RESULT_FORMAT \
                                                    | SAR_ADC_DEFAULT_JUSTIFICATION \
                                                    | SAR_ADC_DEFAULT_ALT_RESOLUTION \
                                           | (uint8)(SAR_ADC_DEFAULT_AVG_SAMPLES_NUM \
                                                   << SAR_ADC_AVG_CNT_OFFSET) \
                                                    | SAR_ADC_AVG_SHIFT_MODE \
                                                    | SAR_ADC_DSI_TRIGGER \
                                                    | SAR_ADC_EOS_DSI_OUT_EN)

#define SAR_ADC_DEFAULT_RANGE_THRES_REG_CFG (SAR_ADC_DEFAULT_LOW_LIMIT \
            | (uint32)((uint32)SAR_ADC_DEFAULT_HIGH_LIMIT << SAR_ADC_RANGE_HIGH_OFFSET))

#define SAR_ADC_DEFAULT_SAMPLE_TIME01_REG_CFG (SAR_ADC_DEFAULT_ACLKS_NUM \
            | (uint32)((uint32)SAR_ADC_DEFAULT_BCLKS_NUM << SAR_ADC_SAMPLE_TIME13_OFFSET))

#define SAR_ADC_DEFAULT_SAMPLE_TIME23_REG_CFG (SAR_ADC_DEFAULT_CCLKS_NUM \
            | (uint32)((uint32)SAR_ADC_DEFAULT_DCLKS_NUM << SAR_ADC_SAMPLE_TIME13_OFFSET))


#endif /* End CY_ADC_SAR_SEQ_SAR_ADC_H */


/* [] END OF FILE */
